@@ -17,6 +17,8 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__all__ = ['handlers', 'protocols', 'GopherExceptions', 'gopherentry',
-           'logger', 'fileext', 'pipe', 'initialization',
-           'initializationTest']
+__all__ = ['handlers', 'protocols', 'GopherExceptions',
+'GopherExceptionsTest', 'gopherentry', 'gopherentryTest',
+           'logger', 'loggerTest',
+'fileext', 'fileextTest', 'pipe', 'initialization',
+           'initializationTest', 'testutil', 'version']
